# PyDotBot

PyDotBot is a library allowing for simple and elegant control of Swarms of DotBots.

<!---
TODO: Show a simple Pythonic example of configuring and controlling dotbots using the library (likely move commands or importing a controller).
TODO: Also show a user interface example of doing the same thing.
-->

## Installing PyDotBot and Supported Versions

PyDotBot is available on PyPI (officially supporting Python 3.8+):
```bash
python -m pip install pydotbot
```

For further information: http://www.dotbots.org/